==> kinesis-0.28.0-sources.jar: software/amazon/awscdk/services/kinesis/CfnStreamConsumer.java <==
package software.amazon.awscdk.services.kinesis;

/**
 * @cloudformationResource AWS::Kinesis::StreamConsumer
 * A CloudFormation `AWS::Kinesis::StreamConsumer`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-04-04T15:06:48.563Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.kinesis.$Module.class, fqn = "@aws-cdk/aws-kinesis.CfnStreamConsumer")
public class CfnStreamConsumer extends software.amazon.awscdk.CfnResource {
    protected CfnStreamConsumer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.kinesis.CfnStreamConsumer.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::Kinesis::StreamConsumer`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnStreamConsumer(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps.class);
    }

    public java.lang.String getStreamConsumerArn() {
        return this.jsiiGet("streamConsumerArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute ConsumerARN
     */
    public java.lang.String getStreamConsumerConsumerArn() {
        return this.jsiiGet("streamConsumerConsumerArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute ConsumerCreationTimestamp
     */
    public java.lang.String getStreamConsumerConsumerCreationTimestamp() {
        return this.jsiiGet("streamConsumerConsumerCreationTimestamp", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute ConsumerName
     */
    public java.lang.String getStreamConsumerConsumerName() {
        return this.jsiiGet("streamConsumerConsumerName", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute ConsumerStatus
     */
    public java.lang.String getStreamConsumerConsumerStatus() {
        return this.jsiiGet("streamConsumerConsumerStatus", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute StreamARN
     */
    public java.lang.String getStreamConsumerStreamArn() {
        return this.jsiiGet("streamConsumerStreamArn", java.lang.String.class);
    }
}

==> kinesis-0.29.0-sources.jar: software/amazon/awscdk/services/kinesis/CfnStreamConsumer.java <==
package software.amazon.awscdk.services.kinesis;

/**
 * A CloudFormation `AWS::Kinesis::StreamConsumer`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-kinesis-streamconsumer.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-04-24T21:04:16.404Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.kinesis.$Module.class, fqn = "@aws-cdk/aws-kinesis.CfnStreamConsumer")
public class CfnStreamConsumer extends software.amazon.awscdk.CfnResource {
    protected CfnStreamConsumer(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.kinesis.CfnStreamConsumer.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::Kinesis::StreamConsumer`.
     * 
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     */
    public CfnStreamConsumer(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, new Object[] { properties });
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.kinesis.CfnStreamConsumerProps.class);
    }

    public java.lang.String getStreamConsumerArn() {
        return this.jsiiGet("streamConsumerArn", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getStreamConsumerConsumerArn() {
        return this.jsiiGet("streamConsumerConsumerArn", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getStreamConsumerConsumerCreationTimestamp() {
        return this.jsiiGet("streamConsumerConsumerCreationTimestamp", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getStreamConsumerConsumerName() {
        return this.jsiiGet("streamConsumerConsumerName", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getStreamConsumerConsumerStatus() {
        return this.jsiiGet("streamConsumerConsumerStatus", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getStreamConsumerStreamArn() {
        return this.jsiiGet("streamConsumerStreamArn", java.lang.String.class);
    }
}
